from iosxe import IosClient
import json

ddd = IosClient("soapgw2", "eb5Swd8Yhq2Snd3eD", "172.24.223.149", 22)

print ddd.get_cpu_load()

jjj = ddd.get_binding_by_ip("100.70.2.1")
print json.dumps(jjj, indent=4, sort_keys=True)

print jjj["mac"] + "  " + jjj["iwaginterface"] + "  " + jjj["aphostname"] + "  " + jjj["SSID"]



#!/usr/bin/python


import functions
import influxdb

class Ard:
    def __init__(self):
        self.test = "test"

    def send_telegram_message(self, message, chatid, token):
        functions.send_telegr(message, chatid, token)

    def get_modules_status(self):
        stat = functions.get_modules_status()
        return stat

    def get_hostname(self):
        hn = functions.get_hostname()
        return str(hn)

    def ping_check(self):
        resp = functions.check_ping()
        return resp


class ArdUnbound:
    def __init__(self, telegram_token, telegram_chat_id):
        self.test = "test"
        self.telegram_token = telegram_token
        self.telegram_chat_id = telegram_chat_id

    def processes_check(self):
        stat = functions.get_modules_status()
        hostn = functions.get_hostname()
        if stat["unbound"] < 50:
            mess1 = "DNS " + hostn + " ERROR. Some Unbound processes are failed"
            functions.send_telegr(mess1, self.telegram_chat_id, self.telegram_token)

        if stat["bfd_c"] < 6:
            mess2 = "DNS " + hostn + " ERROR. Some BFD processes are failed"
            functions.send_telegr(mess2, self.telegram_chat_id, self.telegram_token)

        if stat["bird"] < 1:
            mess3 = "DNS " + hostn + " ERROR. BGP IPv4 process failed"
            functions.send_telegr(mess3, self.telegram_chat_id, self.telegram_token)

        if stat["zabbix"] < 1:
            mess4 = "DNS " + hostn + " ERROR. Zabbix Agent IPv4 process failed"
            functions.send_telegr(mess4, self.telegram_chat_id, self.telegram_token)

        if stat["bird6"] < 1:
            mess5 = "DNS " + hostn + " ERROR. BGP IPv6 process failed"
            functions.send_telegr(mess5, self.telegram_chat_id, self.telegram_token)


class ArdInflux:
    def __init__(self, influxurl):
        self.influxurl = influxurl

    def unbound_stat_to_influx(self):
        hostname = functions.get_hostname()
        data = functions.get_data_from_unbound_stat()
        influxdb.push_unbound_metrics(data, self.influxurl, hostname)



#!/usr/bin/python


import re
import requests
import subprocess
import os


def send_telegr(message, chatid, token):
    r = requests.post(token, data={'chat_id': chatid, 'text': message})
    #print str(r.status_code)
    answr= {'status_code': str(r.status_code), 'reason': str(r.reason)}
    return answr


def get_path_to(app):
    p1 = subprocess.Popen(["which", app], stdout=subprocess.PIPE)
    output1 = p1.communicate()[0]
    return output1.split(".")[0].replace('\n', '')


def get_hostname():
    netst = get_path_to("cat")
    p1 = subprocess.Popen([netst, "/proc/sys/kernel/hostname"], stdout=subprocess.PIPE)
    output1 = p1.communicate()[0]
    return output1.split(".")[0]


def get_modules_status():
    #netst = get_path_to("netstat")
    p = subprocess.Popen(["/usr/bin/netstat", "-ntulp"], stdout=subprocess.PIPE)
    output = p.communicate()[0]
    a2 = re.findall(r'\s+\d+/(\S+)\s+', output)
    val2 = a2
    #print val2

    unbound = 0
    bfd_c = 0
    bird = 0
    zabbix = 0
    bird6 = 0

    cnt = 0
    while cnt < len(a2):
        i = a2[cnt]
        if i == 'unbound':
            unbound = unbound + 1
        elif i == 'bird':
            bird = bird + 1
        elif i == 'bfdd-beacon':
            bfd_c = bfd_c + 1
        elif i == 'zabbix_agentd':
            zabbix = zabbix + 1
        elif i == 'bird6':
            bird6 = bird6 + 1
        cnt = cnt + 1
    answer = {"unbound": unbound, "bfd_c": bfd_c, "bird": bird, "zabbix": zabbix, "bird6": bird6}
    return answer


def mac_parse(mac):
    a = mac.upper()
    pos = a[0] + a[1]
    if pos == "01":
        subscribers_mac = a[2] + a[3] + ":" + a[5] + a[6] + ":" + a[7] + a[8] + ":" + a[10] + a[11] + ":" + a[12] + a[13] + ":" + a[15] + a[16]
    else:
        subscribers_mac = a[0] + a[1] + ":" + a[2] + a[3] + ":" + a[5] + a[6] + ":" + a[7] + a[8] + ":" + a[10] + a[11] + ":" + a[12] + a[13]
    return subscribers_mac


def check_ping():
    hostname = "google.com"
    response = os.system("ping -c 7 " + hostname)
    # and then check the response...
    #print response
    if response == 0:
        pingstatus = "OK"
    else:
        pingstatus = "ERROR"
        #os.system("ifdown ens161;ifdown ens256")
    return pingstatus


def get_data_from_unbound_stat():
    #netst = get_path_to("unbound-control")
    p = subprocess.Popen(["/usr/local/sbin/unbound-control", "stats"], stdout=subprocess.PIPE)
    output = p.communicate()[0]
    mass = str(output).split("\n")
    return mass

#[root@min26dns1 python]# which crontab
#/usr/bin/crontab
#[root@min26dns1 python]# which netstat
#/usr/bin/netstat
#[root@min26dns1 python]# which unbound-control


import imperituroard.core

#df = imperituroard.core.Ard()

#ast = df.send_telegram_message("dima test",

#print ast

#print df.ping_check()


dd = imperituroard.core.ArdUnbound("https://api.telegram.org/bot544376052:AAFBdb6CfxNR6rEGVUAGUc6iLdxdHFLx1IU/sendMessage", "-207244766")

dd.processes_check()


import requests


def push_unbound_metrics(mass, url, database):
    data11 = ''
    for i in mass:
        if i != '':
            d1 = i.split("=")
            name = d1[0]
            val = d1[1]
            data11 = data11 + 'dns,host='+database+',name=' + name + ' value=' + val + '\n'
    requests.post(url, data11)



from setuptools import setup, find_packages

setup(name='imperituroard',
      version='0.7',
      description='Procedures from imperituroard',
      long_description='Different usefull procedures from imperituroard. General pack with all my other frameworks',
      classifiers=['Development Status :: 3 - Alpha',
                   'License :: OSI Approved :: MIT License',
                   'Programming Language :: Python :: 2.7',
                   'Topic :: Text Processing :: Linguistic', ],
      keywords='monitoring additional procedures',
#      url='http://github.com/storborg/funniest',
      author='Dzmitry Buynovskiy',
      author_email='imperituro@mail.com',
      license='MIT',
      packages=find_packages(),
      install_requires=['paramiko', 'requests', 'subprocess.run', 'staros', 'iosxe'],
      include_package_data=True,
      zip_safe=False)
